@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -123,7 +122,7 @@ func NewLinter(out io.Writer, opts *LinterOptions) (*Linter, error) {
 		}
 	}
 
-	var lout io.Writer = ioutil.Discard
+	var lout io.Writer = io.Discard
 	if opts.LogWriter != nil {
 		lout = opts.LogWriter
 	}
@@ -216,7 +215,7 @@ func (l *Linter) GenerateDefaultConfig(dir string) error {
 }
 
 // LintRepository lints YAML workflow files and outputs the errors to given writer. It finds the nearest
-// `.github/workflow` directory based on `dir` and applies lint rules to all YAML worflow files
+// `.github/workflows` directory based on `dir` and applies lint rules to all YAML workflow files
 // under the directory.
 func (l *Linter) LintRepository(dir string) ([]*Error, error) {
 	l.log("Linting all workflow files in repository:", dir)
@@ -276,9 +275,9 @@ func (l *Linter) LintFiles(filepaths []string, project *Project) ([]*Error, erro
 	}
 
 	proc := newConcurrentProcess(runtime.NumCPU())
-	localActions := NewLocalActionsCache(project, l.debugWriter())
 	sema := semaphore.NewWeighted(int64(runtime.NumCPU()))
 	ctx := context.Background()
+	factory := NewLocalActionsCacheFactory(l.debugWriter())
 
 	type workspace struct {
 		path string
@@ -301,11 +300,12 @@ func (l *Linter) LintFiles(filepaths []string, project *Project) ([]*Error, erro
 			// Before entering goroutine, resolve project instance.
 			p = l.projects.At(w.path)
 		}
+		c := factory.GetCache(p) // #173
 
 		eg.Go(func() error {
 			// Bound concurrency on reading files to avoid "too many files to open" error (issue #3)
 			sema.Acquire(ctx, 1)
-			src, err := ioutil.ReadFile(w.path)
+			src, err := os.ReadFile(w.path)
 			sema.Release(1)
 			if err != nil {
 				return fmt.Errorf("could not read %q: %w", w.path, err)
@@ -316,7 +316,7 @@ func (l *Linter) LintFiles(filepaths []string, project *Project) ([]*Error, erro
 					w.path = r // Use relative path if possible
 				}
 			}
-			errs, err := l.check(w.path, src, p, proc, localActions)
+			errs, err := l.check(w.path, src, p, proc, c)
 			if err != nil {
 				return fmt.Errorf("fatal error while checking %s: %w", w.path, err)
 			}
@@ -369,7 +369,7 @@ func (l *Linter) LintFile(path string, project *Project) ([]*Error, error) {
 		project = l.projects.At(path)
 	}
 
-	src, err := ioutil.ReadFile(path)
+	src, err := os.ReadFile(path)
 	if err != nil {
 		return nil, fmt.Errorf("could not read %q: %w", path, err)
 	}
@@ -473,7 +473,7 @@ func (l *Linter) check(path string, content []byte, project *Project, proc *conc
 			NewRuleJobNeeds(),
 			NewRuleAction(localActions),
 			NewRuleEnvVar(),
-			NewRuleStepID(),
+			NewRuleID(),
 			NewRuleGlob(),
 			NewRulePermissions(),
 			NewRuleWorkflowCall(),
