@@ -8,7 +8,6 @@ import (
 	"fmt"
 	"go/format"
 	"io"
-	"io/ioutil"
 	"log"
 	"net/http"
 	"os"
@@ -82,8 +81,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "EnricoMi/publish-unit-test-result-action",
-		tags: []string{"v1"},
-		next: "v2",
+		tags: []string{"v1", "v2"},
+		next: "v3",
 	},
 	{
 		slug: "JamesIves/github-pages-deploy-action",
@@ -97,8 +96,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "Swatinem/rust-cache",
-		tags: []string{"v1"},
-		next: "v2",
+		tags: []string{"v1", "v2"},
+		next: "v3",
 	},
 	{
 		slug: "actions-cool/issues-helper",
@@ -135,6 +134,16 @@ var popularActions = []*action{
 		tags: []string{"v1", "v2", "v3"},
 		next: "v4",
 	},
+	{
+		slug: "actions/configure-pages",
+		tags: []string{"v1"},
+		next: "v2",
+	},
+	{
+		slug: "actions/deploy-pages",
+		tags: []string{"v1"},
+		next: "v2",
+	},
 	{
 		slug: "actions/delete-package-versions",
 		tags: []string{"v1", "v2", "v3"},
@@ -194,6 +203,11 @@ var popularActions = []*action{
 		tags: []string{"v1", "v2", "v3"},
 		next: "v4",
 	},
+	{
+		slug: "actions/upload-pages-artifact",
+		tags: []string{"v1"},
+		next: "v2",
+	},
 	{
 		slug: "aws-actions/configure-aws-credentials",
 		tags: []string{"v1"},
@@ -530,7 +544,7 @@ func (a *app) fetchRemote() (map[string]*actionlint.ActionMetadata, error) {
 						ret <- &fetched{err: fmt.Errorf("request was not successful %s: %s", url, res.Status)}
 						break
 					}
-					body, err := ioutil.ReadAll(res.Body)
+					body, err := io.ReadAll(res.Body)
 					res.Body.Close()
 					if err != nil {
 						ret <- &fetched{err: fmt.Errorf("could not read body for %s: %w", url, err)}
@@ -822,7 +836,7 @@ Flags:`)
 	if quiet {
 		w := log.Writer()
 		defer func() { a.log.SetOutput(w) }()
-		a.log.SetOutput(ioutil.Discard)
+		a.log.SetOutput(io.Discard)
 	}
 
 	a.log.Println("Start generate-popular-actions script")
